@@ -6,7 +6,7 @@ function(n,numbsim,lambda,mu){
 	while (stop==0) {
 		phy2 <- sim2.bd(n,0,lambda,mu)
 		if (class(phy2) == "phylo") { 
-		phytmp <- prune.extinct.taxa(phy2,tol = 0.0000001)
+		phytmp <- drop.extinct(phy2,tol = 0.0000001)
 		if (length(phytmp$tip)== n) {
 			stop = 1
 			}
